yakumo.cinder.v2.consistency_group_snapshot

Package yakumo :: Package cinder :: Package v2 :: Module consistency_group_snapshot |
[hide private]
[frames] | no frames]

# Module consistency_group_snapshot

source code

Resource class and its manager for consistency group snapshot on Block Storage V2 API

Classes | [hide private]
| Resource resource class for consistency group snapshot on Block Storage V2 API
| Manager manager class for consistency group snapshot on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'display_description', mapper.Noop), ('source_cg', 'consistencygr
      oup_id', mapper.List(mapper.Resource('cinder.consistency_group'))), ('
      project', 'project_id', mapper.List(mapper.Resource('project'))), ('us
      er', 'user_id', mapper.List(mapper.Resource('user'))), ('status', 'sta
      tus', mapper.Noop), ('created_at', 'created_at', mapper.DateTime),]